@@ -7,7 +7,7 @@ use Role::Tiny ();
 use Scalar::Util ();
 use Class::Method::Modifiers ();
 
-our $VERSION = '1.11'; # VERSION
+our $VERSION = '1.12'; # VERSION
 
 my ( $store, $roles );
 
@@ -115,7 +115,8 @@ sub class_has {
         ____attrs($set);
     }
     catch {
-        croak($$_);
+        my $e = $_ || $@;
+        croak($$e);
     };
 
     return;
@@ -136,7 +137,8 @@ sub has {
         ____attrs($set);
     }
     catch {
-        croak($$_);
+        my $e = $_ || $@;
+        croak($$e);
     };
 
     return;
@@ -240,7 +242,7 @@ exact::class - Simple class interface extension for exact
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =for markdown [![test](https://github.com/gryphonshafer/exact-class/workflows/test/badge.svg)](https://github.com/gryphonshafer/exact-class/actions?query=workflow%3Atest)
 [![codecov](https://codecov.io/gh/gryphonshafer/exact-class/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/exact-class)
